==> qtwebengine-everywhere-src-5.12.0.tar.xz: qtwebengine-everywhere-src-5.12.0/src/core/visited_links_manager_qt.h <==
/****************************************************************************
**
** Copyright (C) 2017 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of the QtWebEngine module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 3 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL3 included in the
** packaging of this file. Please review the following information to
** ensure the GNU Lesser General Public License version 3 requirements
** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 2.0 or (at your option) the GNU General
** Public license version 3 or any later version approved by the KDE Free
** Qt Foundation. The licenses are as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-2.0.html and
** https://www.gnu.org/licenses/gpl-3.0.html.
**
** $QT_END_LICENSE$
**
****************************************************************************/

//
//  W A R N I N G
//  -------------
//
// This file is not part of the Qt API.  It exists purely as an
// implementation detail.  This header file may change from version to
// version without notice, or even be removed.
//
// We mean it.
//

#ifndef VISITED_LINKS_MANAGER_QT_H
#define VISITED_LINKS_MANAGER_QT_H

#include "qtwebenginecoreglobal_p.h"
#include <QList>
#include <QScopedPointer>

QT_BEGIN_NAMESPACE
class QUrl;
QT_END_NAMESPACE

namespace visitedlink {
class VisitedLinkMaster;
}

class GURL;

namespace QtWebEngineCore {

class ProfileAdapter;
class VisitedLinkDelegateQt;

class QWEBENGINECORE_PRIVATE_EXPORT VisitedLinksManagerQt {

public:
    virtual~VisitedLinksManagerQt();
    VisitedLinksManagerQt(ProfileAdapter *profileAdapter);

    void deleteAllVisitedLinkData();
    void deleteVisitedLinkDataForUrls(const QList<QUrl> &);

    bool containsUrl(const QUrl &) const;

private:
    void addUrl(const GURL &);
    friend class WebContentsDelegateQt;

    QScopedPointer<visitedlink::VisitedLinkMaster> m_visitedLinkMaster;
    QScopedPointer<VisitedLinkDelegateQt> m_delegate;
};

} // namespace QtWebEngineCore

#endif // WEB_ENGINE_VISITED_LINKS_MANAGER_H

==> qtwebengine-everywhere-src-5.13.1.tar.xz: qtwebengine-everywhere-src-5.13.1/src/core/visited_links_manager_qt.h <==
/****************************************************************************
**
** Copyright (C) 2017 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of the QtWebEngine module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 3 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL3 included in the
** packaging of this file. Please review the following information to
** ensure the GNU Lesser General Public License version 3 requirements
** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 2.0 or (at your option) the GNU General
** Public license version 3 or any later version approved by the KDE Free
** Qt Foundation. The licenses are as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-2.0.html and
** https://www.gnu.org/licenses/gpl-3.0.html.
**
** $QT_END_LICENSE$
**
****************************************************************************/

//
//  W A R N I N G
//  -------------
//
// This file is not part of the Qt API.  It exists purely as an
// implementation detail.  This header file may change from version to
// version without notice, or even be removed.
//
// We mean it.
//

#ifndef VISITED_LINKS_MANAGER_QT_H
#define VISITED_LINKS_MANAGER_QT_H

#include "qtwebenginecoreglobal_p.h"
#include <QList>
#include <QScopedPointer>

QT_BEGIN_NAMESPACE
class QUrl;
QT_END_NAMESPACE

namespace visitedlink {
class VisitedLinkMaster;
}

class GURL;

namespace QtWebEngineCore {

class ProfileQt;
class VisitedLinkDelegateQt;

class Q_WEBENGINECORE_PRIVATE_EXPORT VisitedLinksManagerQt {

public:
    virtual~VisitedLinksManagerQt();
    VisitedLinksManagerQt(ProfileQt *profile, bool persistVisitedLinks);

    void deleteAllVisitedLinkData();
    void deleteVisitedLinkDataForUrls(const QList<QUrl> &);

    bool containsUrl(const QUrl &) const;

private:
    void addUrl(const GURL &);
    friend class WebContentsDelegateQt;

    QScopedPointer<visitedlink::VisitedLinkMaster> m_visitedLinkMaster;
    QScopedPointer<VisitedLinkDelegateQt> m_delegate;
};

} // namespace QtWebEngineCore

#endif // WEB_ENGINE_VISITED_LINKS_MANAGER_H
